==> digikam_4.12.0.orig.tar.bz2: digikam-4.12.0/extra/kipi-plugins/shwup/kipiplugin_shwup.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Shwup Export
Name=Shwup Export
Name[ast]=Shwup Export
Name[bg]=Изнасяне към Shwup
Name[bs]=Shwup Izvoz
Name[ca]=Exportador a Shwup
Name[ca@valencia]=Exportador a Shwup
Name[cs]=Export Shwup
Name[da]=Shwup-eksport
Name[de]=Shwup-Export
Name[el]=Εξαγωγή Shwup
Name[en_GB]=Shwup Export
Name[es]=Exportar a Shwup
Name[et]=Shwupi eksport
Name[eu]=Shwup esportatzea
Name[fi]=Shwup-vienti
Name[fr]=Exportation « Shwup »
Name[ga]=Easpórtáil Shwup
Name[gl]=Exportación a Shwup
Name[hu]=Shwup exportáló
Name[is]=Shwup útflutningur
Name[it]=Esportazione a Shwup
Name[km]=ការ​នាំ​ចេញ Shwup
Name[lv]=Eksportēt uz Shwup
Name[nb]=Shwup-eksport
Name[nds]=Shwup-Exporteren
Name[nl]=Shwup-export
Name[pl]=Eksport Shwup
Name[pt]=Exportação para o Shwup
Name[pt_BR]=Exportar para o Shwup
Name[ro]=Export Shwup
Name[ru]=Экспорт в Shwup
Name[sk]=Shwup export
Name[sl]=Izvoz v Shwup
Name[sv]=Export till Shwup
Name[th]=ส่งออกไปยังบริการ Shwup
Name[tr]=Shwup Aktarımı
Name[uk]=Експорт до Shwup
Name[x-test]=xxShwup Exportxx
Name[zh_CN]=Shwup 导出
Name[zh_TW]=Shwup 匯出
Comment=A tool to export images to a remote Shwup web service
Comment[ast]=Una ferramienta pa esportar imáxenes a un serviciu web remotu Shwup
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Shwup
Comment[bs]=Alat za izvoz slika na udaljeni Shwup web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Shwup
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Shwup
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Shwup
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Shwup-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Shwup-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Shwup
Comment[en_GB]=A tool to export images to a remote Shwup web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Shwup
Comment[et]=Tööriist piltide eksportimiseks Shwupi veebiteenusesse
Comment[eu]=Urruneko Shwup web zerbitzura irudiak esportatzeko tresna
Comment[fi]=Kuvien vienti Shwup-verkkopalveluun
Comment[fr]=Un outil d'exportation d'images vers le service en ligne « Shwup »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Shwup
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Shwup remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Shwup webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Shwup vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Shwup
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​សេវា​បណ្តាញ Shwup ​ពីចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz Shwup tīmekļa servisu
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Shwup-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na en feern Shwup-Nettdeenst exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Shwub-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Shwup
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Shwup
Comment[pt_BR]=Ferramenta para exportar imagens para o Shwup
Comment[ro]=O unealtă de exportat imagini pe serviciul web Shwup
Comment[ru]=Инструмент для экспорта изображений в веб-службу Shwup
Comment[sk]=Nástroj na export obrázkov do Shwup webovej služby
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Shwup
Comment[sv]=Ett verktyg för att exportera bilder till en Shwup fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Shwup
Comment[tr]=Resimleri uzak bir Shwup web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Shwup
Comment[x-test]=xxA tool to export images to a remote Shwup web servicexx
Comment[zh_CN]=一个将图像导出到远程 Shwup 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Shwup 網頁服務的工具
Type=Service
Icon=kipi-shwup
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_shwup
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Timothée Groleau, timothee at muvee dot com

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/shwup/kipiplugin_shwup.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Shwup Export
Name=Shwup Export
Name[ast]=Shwup Export
Name[bg]=Изнасяне към Shwup
Name[bs]=Shwup Izvoz
Name[ca]=Exportador a Shwup
Name[ca@valencia]=Exportador a Shwup
Name[cs]=Export Shwup
Name[da]=Shwup-eksport
Name[de]=Shwup-Export
Name[el]=Εξαγωγή Shwup
Name[en_GB]=Shwup Export
Name[es]=Exportar a Shwup
Name[et]=Shwupi eksport
Name[eu]=Shwup esportatzea
Name[fi]=Shwup-vienti
Name[fr]=Export « Shwup »
Name[ga]=Easpórtáil Shwup
Name[gl]=Exportación a Shwup
Name[hu]=Shwup exportáló
Name[is]=Shwup útflutningur
Name[it]=Esportazione a Shwup
Name[km]=ការ​នាំ​ចេញ Shwup
Name[lv]=Eksportēt uz Shwup
Name[nb]=Shwup-eksport
Name[nds]=Shwup-Exporteren
Name[nl]=Shwup-export
Name[pl]=Eksport Shwup
Name[pt]=Exportação para o Shwup
Name[pt_BR]=Exportar para o Shwup
Name[ro]=Export Shwup
Name[ru]=Экспорт в Shwup
Name[sk]=Shwup export
Name[sl]=Izvoz v Shwup
Name[sv]=Export till Shwup
Name[th]=ส่งออกไปยังบริการ Shwup
Name[tr]=Shwup Aktarımı
Name[uk]=Експорт до Shwup
Name[x-test]=xxShwup Exportxx
Name[zh_CN]=Shwup 导出
Name[zh_TW]=Shwup 匯出
Comment=A tool to export images to a remote Shwup web service
Comment[ast]=Una ferramienta pa esportar imáxenes a un serviciu web remotu Shwup
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Shwup
Comment[bs]=Alat za izvoz slika na udaljeni Shwup web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Shwup
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Shwup
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Shwup
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Shwup-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Shwup-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού Shwup
Comment[en_GB]=A tool to export images to a remote Shwup web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Shwup
Comment[et]=Tööriist piltide eksportimiseks Shwupi veebiteenusesse
Comment[eu]=Urruneko Shwup web zerbitzura irudiak esportatzeko tresna
Comment[fi]=Kuvien vienti Shwup-verkkopalveluun
Comment[fr]=Un outil d'export d'images vers le service en ligne « Shwup »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Shwup
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Shwup remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Shwup webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjarlæga Shwup vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Shwup
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​សេវា​បណ្តាញ Shwup ​ពីចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz Shwup tīmekļa servisu
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Shwup-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na en feern Shwup-Nettdeenst exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Shwub-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Shwup
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Shwup
Comment[pt_BR]=Ferramenta para exportar imagens para o Shwup
Comment[ro]=O unealtă de exportat imagini pe serviciul web Shwup
Comment[ru]=Инструмент для экспорта изображений в веб-службу Shwup
Comment[sk]=Nástroj na export obrázkov do Shwup webovej služby
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Shwup
Comment[sv]=Ett verktyg för att exportera bilder till en Shwup fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Shwup
Comment[tr]=Resimleri uzak bir Shwup web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Shwup
Comment[x-test]=xxA tool to export images to a remote Shwup web servicexx
Comment[zh_CN]=一个将图像导出到远程 Shwup 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Shwup 網頁服務的工具
Type=Service
Icon=kipi-shwup
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_shwup
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Timothée Groleau, timothee at muvee dot com
